@@ -4,7 +4,7 @@ from nb_log import nb_log_config_default
 from nb_log.monkey_print import nb_print, patch_print, reverse_patch_print,stdout_write,stderr_write,print_raw,is_main_process,only_print_on_main_process
 from nb_log.log_manager import LogManager, LoggerLevelSetterMixin, LoggerMixin, LoggerMixinDefaultWithFileHandler, get_logger, get_logger_with_filehanlder
 
-if nb_log_config_default.WARNING_PYCHARM_COLOR_SETINGS:
+if nb_log_config_default.SHOW_PYCHARM_COLOR_SETINGS:
      only_print_on_main_process(
             """
             1)使用pycharm时候，强烈建议按下面的重新自定义设置pycharm的console里面的主题颜色，否则颜色显示瞎眼，代码里面规定的颜色只是大概的红黄蓝绿。在不同的ide软件和主题、字体下是不同的显示效果，需要用户自己设置。
